==> gtkmm_0.9.15.orig.tar.gz: Gtk---0.9.15/examples/testme.cc <==
#include <iostream.h>
#include <stdio.h>
#include <gtk--.h>

// Main idea of this test program is to test how connections work in gtk.
//
// It does not do anything too neat, just prints some dummy things to
// console.

class MyWin : public Gtk_Window
{
    Gtk_VBox box;
    Gtk_ScrolledWindow swin;
    Gtk_Button b;
    Gtk_Tooltips btip;
    Gtk_Entry text;
    Gtk_Viewport footext;
    
    
    // Connection-objects can be used for disconecting a connection.
    // it isnt necessary to know about these at all, they are here
    // for easier use of connect().
    Connection c1,c2,c3,c4;
    bool init;
public:  
    Signal1<GdkEventKey *> keyPressed;
    Signal1<gint> foo;
    Signal0 test;
    Signal0 test2;
    
private:
    Gtk_FileSelection *fs;
    gint selectionclosed(GdkEventAny*) {
	printf("Selectionclosed\n");
	// WHY DOESNT PASSING THIS RETURN VALUE WORK? It should NOT delete
	// GtkFileSelection object when this returns TRUE... but it does
        // and I have no idea why... I'd guess gtk never gets this TRUE..
        // needs investigating.
	return TRUE;
    }
    void buttoncanceled() {
	cout << "File NOT Selected " << fs->get_filename() << endl;
	fs->hide();
    }
    void buttonpressed() {
	cout << "File Selected " << fs->get_filename() << endl;
	fs->hide();
    }
    void showfileselection(){
	if (!fs) { 
	    // seems that creating new widget takes time.. 
	    // better do it once and then just hide and show that one
	    // this way you wont get million similar windows to the 
	    // screen either...
	    fs=new Gtk_FileSelection("File Selection");
	    connect_to_method(fs->ok_button.clicked, this, &buttonpressed);
	    connect_to_method(fs->cancel_button.clicked,this,&buttoncanceled);
	    connect_to_method(fs->delete_event, this, &selectionclosed);
	}
	fs->show();
    }
    	
    void keypress(GdkEventKey *event)
    { 
	// sending foo and keyPressed-signals.
	foo(10); keyPressed(event); 
	test();
	c1.disconnect(); // now we'll test disconnecting the connections.
	c2.disconnect();
	c3.disconnect();
	c4.disconnect();
	printf("Keypress was %d\n",event->keyval);
    }
    
public:
    
    virtual gint expose_event_impl(GdkEventExpose* e) { // catch expose events. 
	printf("expose!\n");
	Gtk_Widget::expose_event_impl(e);
	return 0;
    }
    
    MyWin();
};

MyWin::MyWin()
    : Gtk_Window(GTK_WINDOW_TOPLEVEL),
      box(true,0),
      b("Push me"),
      init(false), fs(0)
{
    // vbox
    add(&box);
    box.show();
    
    // button
    box.pack_start(&b);
    box.pack_start(&swin);
    swin.add(&footext);
   
    connect_to_method(b.clicked,this,&showfileselection);
   
    btip.set_tip(&b,"Press this to get fileselection","private string");
    b.show();
    

    // text entry
    box.pack_start(&text);
    text.show();
    footext.show();
    swin.show();
    
}

Gtk_Main *mainwidget;

static int myquit(GdkEventAny*) {
    printf("MYQUIT\n");
    mainwidget->quit();
    return 0;
}

int
main(int argc, char *argv[])
{
    Gtk_Main myapp(&argc, &argv);
    mainwidget=&myapp;
    MyWin mywin;
    connect_to_function(mywin.delete_event,&myquit);
    
    mywin.show();
    
    myapp.run();
    return 0;
}

==> gtkmm_1.0.3.orig.tar.gz: Gtk---1.0.3/examples/testme.cc <==
#include <iostream.h>
#include <stdio.h>
#include <gtk--.h>

// Main idea of this test program is to test how connections work in gtk.
//
// It does not do anything too neat, just prints some dummy things to
// console.

class MyWin : public Gtk_Window
{
    Gtk_VBox box;
    Gtk_ScrolledWindow swin;
    Gtk_Button b;
    Gtk_Tooltips btip;
    Gtk_Entry text;
    Gtk_Viewport footext;
    
    
    // Connection-objects can be used for disconecting a connection.
    // it isnt necessary to know about these at all, they are here
    // for easier use of connect().
    Connection c1,c2,c3,c4;
    bool init;
public:  
    Signal1<GdkEventKey *> keyPressed;
    Signal1<gint> foo;
    Signal0 test;
    Signal0 test2;
    
private:
    Gtk_FileSelection *fs;
    gint selectionclosed(GdkEventAny*) {
	printf("Selectionclosed\n");
	// WHY DOESNT PASSING THIS RETURN VALUE WORK? It should NOT delete
	// GtkFileSelection object when this returns TRUE... but it does
        // and I have no idea why... I'd guess gtk never gets this TRUE..
        // needs investigating.

	// I think we now return it correctly, but...
	// returning FALSE works, but it'll delete the dialog
	// retyrning TRUE does something odd, the main window
	// nor future widget's resize events doesny work...
	//fs->hide();
	//fs=0;
	return TRUE;
    }
    void buttoncanceled() {
	cout << "File NOT Selected " << fs->get_filename() << endl;
	fs->hide();
    }
    void buttonpressed() {
	cout << "File Selected " << fs->get_filename() << endl;
	fs->hide();
    }
    void showfileselection(){
	if (!fs) { 
	    // seems that creating new widget takes time.. 
	    // better do it once and then just hide and show that one
	    // this way you wont get million similar windows to the 
	    // screen either...
	    fs=new Gtk_FileSelection("File Selection");
	    connect_to_method(fs->get_ok_button()->clicked, this, &buttonpressed);
	    connect_to_method(fs->get_cancel_button()->clicked,this,&buttoncanceled);
	    connect_to_method(fs->delete_event, this, &selectionclosed);
	}
	fs->show();
    }
    	
    void keypress(GdkEventKey *event)
    { 
	// sending foo and keyPressed-signals.
	foo(10); keyPressed(event); 
	test();
	c1.disconnect(); // now we'll test disconnecting the connections.
	c2.disconnect();
	c3.disconnect();
	c4.disconnect();
	printf("Keypress was %d\n",event->keyval);
    }
    
public:
    
    virtual gint expose_event_impl(GdkEventExpose* e) { // catch expose events. 
	printf("expose!\n");
	Gtk_Widget::expose_event_impl(e);
	return 0;
    }
    
    MyWin();
};

MyWin::MyWin()
    : Gtk_Window(GTK_WINDOW_TOPLEVEL),
      box(true,0),
      b("Push me"),
      init(false), fs(0)
{
    // vbox
    add(&box);
    box.show();
    
    // button
    box.pack_start(b);
    box.pack_start(swin);
    swin.add(&footext);
   
    connect_to_method(b.clicked,this,&showfileselection);
   
    btip.set_tip(b,"Press this to get fileselection","private string");
    b.show();
    

    // text entry
    box.pack_start(text);
    text.show();
    footext.show();
    swin.show();
    
}

Gtk_Main *mainwidget;

static int myquit(GdkEventAny*) {
    printf("MYQUIT\n");
    mainwidget->quit();
    return 0;
}

int
main(int argc, char *argv[])
{
    Gtk_Main myapp(&argc, &argv);
    mainwidget=&myapp;
    MyWin mywin;
    connect_to_function(mywin.delete_event,&myquit);
    
    mywin.show();
    
    myapp.run();
    return 0;
}
